summaryrefslogtreecommitdiff
path: root/src/parser/antlr_input.h
diff options
context:
space:
mode:
authorMorgan Deters <mdeters@gmail.com>2010-10-12 21:49:07 +0000
committerMorgan Deters <mdeters@gmail.com>2010-10-12 21:49:07 +0000
commitb5a68d2181e23094558069058663460b04b2303a (patch)
treedd8ae9d705988623183e0a1b53258c9d6c1587e2 /src/parser/antlr_input.h
parent3d97646be5eb3f2b50028875f4d899698228e8c7 (diff)
fix some leaks in parser, add debug code to node manager to find more
Diffstat (limited to 'src/parser/antlr_input.h')
-rw-r--r--src/parser/antlr_input.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/parser/antlr_input.h b/src/parser/antlr_input.h
index 82b15d199..e55e07efd 100644
--- a/src/parser/antlr_input.h
+++ b/src/parser/antlr_input.h
@@ -28,9 +28,10 @@
#include <string>
#include <vector>
-#include "input.h"
-#include "parser_options.h"
-#include "parser_exception.h"
+#include "parser/input.h"
+#include "parser/parser_options.h"
+#include "parser/parser_exception.h"
+#include "parser/bounded_token_buffer.h"
#include "expr/expr.h"
#include "expr/expr_manager.h"
#include "util/Assert.h"
@@ -117,10 +118,11 @@ class AntlrInput : public Input {
/** The ANTLR3 input stream associated with this input. */
pANTLR3_INPUT_STREAM d_antlr3InputStream;
/** The ANTLR3 token stream associated with this input. We only need this so we can free it on exit.
* This is set by <code>setLexer</code>.
* NOTE: We assume that we <em>can</em> free it on exit. No sharing! */
- pANTLR3_COMMON_TOKEN_STREAM d_tokenStream;
+ pBOUNDED_TOKEN_BUFFER d_tokenBuffer;
/** Turns an ANTLR3 exception into a message for the user and calls <code>parseError</code>. */
static void reportError(pANTLR3_BASE_RECOGNIZER recognizer);
generated by cgit on debian on lair
@@ -117,10 +118,11 @@ class AntlrInput : public Input {
/** The ANTLR3 input stream associated with this input. */
pANTLR3_INPUT_STREAM d_antlr3InputStream;
- /** The ANTLR3 token stream associated with this input. We only need this so we can free it on exit.
+ /** The ANTLR3 bounded token buffer associated with this input.
+ * We only need this so we can free it on exit.
* This is set by <code>setLexer</code>.
* NOTE: We assume that we <em>can</em> free it on exit. No sharing! */
contact matthew@masot.net with questions or feedback